What is new? (Change log)
=========================

The change log keeps you informed about newly introduced or changed
features and behavior of PyAstronomy.

New version will, of course, contain bug fixes for bugs we became aware of.
Most likely, we will also have introduced new, better bugs to keep things
interesting...

.. toctree::
   :maxdepth: 1
   
   from0120to0130.rst
   from0110to0120.rst
   from0100to0110.rst
   from090to0100.rst
   from081to090.rst
   from070to080.rst
   from060to070.rst
   from050to060.rst
   from040to050.rst
   from030to040.rst
   from020to030.rst